// src/identity-account-v2-account-accounts.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/identity-account-v2-account-accounts.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressAccountApiAccountServiceUrl(opts) {
  const domainToMappings = {
    "api._api_base_domain_": [
      {
        srcPath: "/account-server",
        destPath: ""
      }
    ],
    "www._base_domain_": [
      {
        srcPath: "/_api/account-server",
        destPath: ""
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/account-server",
        destPath: ""
      },
      {
        srcPath: "/account-server",
        destPath: ""
      }
    ],
    "premium._base_domain_": [
      {
        srcPath: "/_api/account-server",
        destPath: ""
      }
    ],
    "editor._base_domain_": [
      {
        srcPath: "/_api/account-server",
        destPath: ""
      }
    ],
    "blocks._base_domain_": [
      {
        srcPath: "/_api/account-server",
        destPath: ""
      }
    ],
    "create.editorx": [
      {
        srcPath: "/_api/account-server",
        destPath: ""
      }
    ],
    "bo._base_domain_": [
      {
        srcPath: "/account-server",
        destPath: ""
      }
    ],
    "wixbo.ai": [
      {
        srcPath: "/account-server",
        destPath: ""
      }
    ],
    "wix-bo.com": [
      {
        srcPath: "/account-server",
        destPath: ""
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/accounts",
        destPath: ""
      },
      {
        srcPath: "/accounts/v1/accounts",
        destPath: "/v1/accounts"
      },
      {
        srcPath: "/accounts/v1/account",
        destPath: "/v1/account"
      }
    ],
    "users._base_domain_": [
      {
        srcPath: "/_api/account-server",
        destPath: ""
      }
    ],
    "*.dev.wix-code.com": [
      {
        srcPath: "/_api/account-server",
        destPath: ""
      }
    ],
    "twins._base_domain_": [
      {
        srcPath: "/_api/account-server",
        destPath: ""
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_user-management_accounts";
function createAccount(payload) {
  function __createAccount({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.account.v2.account",
      method: "POST",
      methodFqn: "com.wixpress.account.api.AccountService.createAccount",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAccountApiAccountServiceUrl({
        protoPath: "/v1/accounts/create",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __createAccount;
}
function createAccountForMyUser(payload) {
  function __createAccountForMyUser({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.account.v2.account",
      method: "POST",
      methodFqn: "com.wixpress.account.api.AccountService.createAccountForMyUser",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAccountApiAccountServiceUrl({
        protoPath: "/v1/accounts",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "account.dateCreated" },
            { path: "account.dateUpdated" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __createAccountForMyUser;
}
function listChildAccounts(payload) {
  function __listChildAccounts({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.account.v2.account",
      method: "GET",
      methodFqn: "com.wixpress.account.api.AccountService.listChildAccounts",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAccountApiAccountServiceUrl({
        protoPath: "/v1/account/child-accounts",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __listChildAccounts;
}

// src/identity-account-v2-account-accounts.universal.ts
var AccountStatus = /* @__PURE__ */ ((AccountStatus2) => {
  AccountStatus2["ACTIVE"] = "ACTIVE";
  AccountStatus2["BLOCKED"] = "BLOCKED";
  AccountStatus2["DELETED"] = "DELETED";
  return AccountStatus2;
})(AccountStatus || {});
var CoBranding = /* @__PURE__ */ ((CoBranding2) => {
  CoBranding2["None"] = "None";
  CoBranding2["CoBranded"] = "CoBranded";
  CoBranding2["CoBranded_Customer_New"] = "CoBranded_Customer_New";
  CoBranding2["CoBranded_Customer_Existing"] = "CoBranded_Customer_Existing";
  return CoBranding2;
})(CoBranding || {});
async function createAccount2(user, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    user,
    roles: options?.roles
  });
  const reqOpts = createAccount(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { user: "$[0]", roles: "$[1].roles" },
        singleArgumentUnchanged: false
      },
      ["user", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function createAccountForMyUser2(options) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    accountName: options?.accountName,
    accountImg: options?.accountImg,
    studio: options?.studio
  });
  const reqOpts = createAccountForMyUser(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          accountName: "$[0].accountName",
          accountImg: "$[0].accountImg",
          studio: "$[0].studio"
        },
        singleArgumentUnchanged: false
      },
      ["options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function listChildAccounts2(options) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    paging: options?.paging
  });
  const reqOpts = listChildAccounts(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { paging: "$[0].paging" },
        singleArgumentUnchanged: false
      },
      ["options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}

// src/identity-account-v2-account-accounts.public.ts
function createAccount3(httpClient) {
  return (user, options) => createAccount2(
    user,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function createAccountForMyUser3(httpClient) {
  return (options) => createAccountForMyUser2(
    options,
    // @ts-ignore
    { httpClient }
  );
}
function listChildAccounts3(httpClient) {
  return (options) => listChildAccounts2(
    options,
    // @ts-ignore
    { httpClient }
  );
}

// src/identity-account-v2-account-accounts.context.ts
import { createRESTModule } from "@wix/sdk-runtime/rest-modules";
var createAccount4 = /* @__PURE__ */ createRESTModule(createAccount3);
var createAccountForMyUser4 = /* @__PURE__ */ createRESTModule(createAccountForMyUser3);
var listChildAccounts4 = /* @__PURE__ */ createRESTModule(listChildAccounts3);
export {
  AccountStatus,
  CoBranding,
  createAccount4 as createAccount,
  createAccountForMyUser4 as createAccountForMyUser,
  listChildAccounts4 as listChildAccounts
};
//# sourceMappingURL=index.mjs.map