import { HttpClient, MaybeContext, BuildRESTFunction } from '@wix/sdk-types';
import { User, CreateAccountOptions, CreateAccountResponse, CreateAccountForMyUserOptions, AccountResponse, ListChildAccountsOptions, ListChildAccountsResponse } from './index.typings.mjs';
export { Account, AccountInfo, AccountProperties, AccountStatus, AccountV2, AccountsResponse, CoBranding, CreateAccountAndAssignUserRequest, CreateAccountForMyUserRequest, CreateAccountRequest, CreateAccountTenantRequest, CreateAccountTenantResponse, DeleteAccountRequest, Email, EmptyResponse, GetAccountRequest, GetAccountsRequest, GetMyAccountRequest, GetMyUserAccountsRequest, GetParentAccountInfoRequest, GetParentAccountInfoResponse, GetSubAccountsRequest, GetSubAccountsResponse, GetUserAccountRequest, GetUserAccountsRequest, IsTeamRequest, IsTeamResponse, ListChildAccountsRequest, MarkAccountFlagRequest, MarkAccountFlagRequestFlagOneOf, Paging, PagingMetadata, RemoveParent, SetIsReadOnlyAccountRequest, SsoIdentity, SubAccountInfo, UpdateAccountRequest, UpdateParentAccountRequest, UpdateParentAccountRequestUpdateOneOf, UpdateParentAccountResponse, UpdateSlugRequest, UserDetails } from './index.typings.mjs';

declare function createAccount$1(httpClient: HttpClient): CreateAccountSignature;
interface CreateAccountSignature {
    /**
     * Creates a new Wix account, and creates a new Wix user as the account owner.
     * The newly created account is a child account of the account used to create it, making that account its parent.
     *
     * > **Important**: This call requires an account level API key and cannot be authenticated with the standard authorization header. API keys are currently available to selected beta users only.
     * @param - The user to create under the new account, with the roles defined in `roles`.
     * @param - Filter options.
     */
    (user: User, options?: CreateAccountOptions | undefined): Promise<CreateAccountResponse>;
}
/** @internal */
declare function createAccountForMyUser$1(httpClient: HttpClient): CreateAccountForMyUserSignature;
interface CreateAccountForMyUserSignature {
    /**
     * creates account for the logged in user
     */
    (options?: CreateAccountForMyUserOptions | undefined): Promise<AccountResponse>;
}
declare function listChildAccounts$1(httpClient: HttpClient): ListChildAccountsSignature;
interface ListChildAccountsSignature {
    /**
     * Retrieves a list of child account IDs for the requesting account.
     * If no child accounts exist, an empty list will be returned.
     *
     * > **Important**: This call requires an account level API key and cannot be authenticated with the standard authorization header. API keys are currently available to selected beta users only.
     * @param - Filter options.
     */
    (options?: ListChildAccountsOptions | undefined): Promise<ListChildAccountsResponse>;
}

declare const createAccount: MaybeContext<BuildRESTFunction<typeof createAccount$1> & typeof createAccount$1>;
/** @internal */
declare const createAccountForMyUser: MaybeContext<BuildRESTFunction<typeof createAccountForMyUser$1> & typeof createAccountForMyUser$1>;
declare const listChildAccounts: MaybeContext<BuildRESTFunction<typeof listChildAccounts$1> & typeof listChildAccounts$1>;

export { AccountResponse, CreateAccountForMyUserOptions, CreateAccountOptions, CreateAccountResponse, ListChildAccountsOptions, ListChildAccountsResponse, User, createAccount, createAccountForMyUser, listChildAccounts };
