import { CreateAccountRequest as CreateAccountRequest$1, CreateAccountResponse as CreateAccountResponse$1, CreateAccountForMyUserRequest as CreateAccountForMyUserRequest$1, AccountResponse as AccountResponse$1, ListChildAccountsRequest as ListChildAccountsRequest$1, ListChildAccountsResponse as ListChildAccountsResponse$1 } from './index.typings.mjs';
import '@wix/sdk-types';

interface AccountV2 {
    /**
     * Account ID.
     * @format GUID
     */
    accountId?: string;
}
interface Account {
    /**
     * Account ID.
     * @format GUID
     */
    accountId?: string;
    /** Account slug - used in the free URL prefix */
    slug?: string;
    /** Account name (display) */
    accountName?: string | null;
    /**
     * DEPRECATED field of account image
     * @deprecated
     */
    accountImg?: string | null;
    /** account status */
    status?: AccountStatusWithLiterals;
    /** account owner user id */
    accountOwner?: string;
    /** account extra properties */
    accountProperties?: AccountProperties;
    /** the account creation date */
    dateCreated?: Date | null;
    /** last time account was updated */
    dateUpdated?: Date | null;
}
/** enum with all available statuses of account */
declare enum AccountStatus {
    ACTIVE = "ACTIVE",
    BLOCKED = "BLOCKED",
    DELETED = "DELETED"
}
/** @enumType */
type AccountStatusWithLiterals = AccountStatus | 'ACTIVE' | 'BLOCKED' | 'DELETED';
/** All relevant account properties */
interface AccountProperties {
    /** Whether this account is a team account. */
    isTeam?: boolean;
    /**
     * Account image (display)
     * relevant mainly for CoBranded accounts
     */
    accountImg?: string | null;
    /**
     * the account banner (display)
     * relevant mainly for CoBranded accounts
     */
    accountBanner?: string | null;
    /**
     * the account logo (display)
     * wll be shown as the account logo in the UI (top right corner, contributor list etc..)
     */
    accountLogo?: string | null;
    /**
     * account co branding flag (if exists)
     * an enum for CoBranding flag contains 4 possible options:
     * None - the account is not CoBranded
     * CoBranded - the account has a CoBranding flag
     * CoBranded_Customer_New - the account is a contributor of a CoBranded account. This account was created because of the contributor invite
     * CoBranded_Customer_Existing - the account is a contributor of a CoBranded account. This account was created before the invite of the contributor invite
     */
    coBranding?: CoBrandingWithLiterals;
    /** account's website URL (shown on co branding customers sites) */
    websiteUrl?: string | null;
    /** the id of the parent account of this account, if it has a parent */
    parentAccountId?: string | null;
}
/** co branding flag options for account */
declare enum CoBranding {
    None = "None",
    CoBranded = "CoBranded",
    CoBranded_Customer_New = "CoBranded_Customer_New",
    CoBranded_Customer_Existing = "CoBranded_Customer_Existing"
}
/** @enumType */
type CoBrandingWithLiterals = CoBranding | 'None' | 'CoBranded' | 'CoBranded_Customer_New' | 'CoBranded_Customer_Existing';
interface Paging {
    /** Number of items to load. */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
interface AccountResponse {
    account?: Account;
}
interface CreateAccountRequest {
    /** The user to create under the new account, with the roles defined in `roles`. */
    user: User;
    /**
     * Roles to be assigned to the user in the new account. To retrieve all available roles, call Get Roles Info in the Users API.
     * Default: OWNER.
     */
    roles?: string[] | null;
}
/** A User to be created under an implicitly provided accountId: must have a unique email. */
interface User {
    /** User's unique email address details. Required. */
    email?: Email;
    /** User's single sign on identity, when the user is identified via SSO authentication response token params, as specified by [OpenID Connect](https://openid.net/developers/how-connect-works/) (aka. OIDC) protocol. */
    ssoIdentities?: SsoIdentity[];
    /** Additional user details. */
    userDetails?: UserDetails;
}
/** User's email address. */
interface Email {
    /**
     * User's email address.
     * @format EMAIL
     */
    emailAddress?: string;
    /** Whether the caller has verified the user's email address. */
    isVerified?: boolean;
}
/** Single Sign On (aka. SSO) identity; user is identified via SSO authentication response token params, as specified by OpenID Connect (aka. OIDC) protocol */
interface SsoIdentity {
    /** An SSO setting (URLs, clientId, secret, etc. as required by OIDC protocol) for a specific Identity-Provider (aka. IdP) for a specific Wix account. */
    ssoId?: string;
    /**
     * User ID as stored in IdP. For example a "sub" claim of OIDC protocol,
     * or any other alternative, specified by IdP (Identity Provider).
     */
    userId?: string;
}
/** additional user details */
interface UserDetails {
    /**
     * User's first name.
     * @maxLength 64
     */
    firstName?: string | null;
    /**
     * User's last name.
     * @maxLength 64
     */
    lastName?: string | null;
    /**
     * URL to location of user's profile picture.
     * @format WEB_URL
     */
    profilePictureUrl?: string | null;
    /**
     * User's preferred language in [ISO 639-1:2002](https://en.wikipedia.org/wiki/ISO_639-1) format. For example, "en", "es".
     * @maxLength 2
     */
    language?: string | null;
    /**
     * Original Client IP from which a request was made.
     * This is useful in case where a createUser API is called by some server call, which, in turn, has been called by some client from another IP.
     * Wix checks this IP against the [OFAC sanctioned countries](https://ofac.treasury.gov/sanctions-programs-and-country-information).
     */
    clientIp?: string | null;
}
interface CreateAccountResponse {
    /** The created account. */
    account?: AccountV2;
}
interface CreateAccountForMyUserRequest {
    /** the account name */
    accountName?: string | null;
    /**
     * account image url
     * @format WEB_URL
     */
    accountImg?: string | null;
    /** whether to mark the account as `studio` */
    studio?: boolean;
}
interface PagingMetadata {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
}
interface ListChildAccountsRequest {
    /**
     * Paging options to limit and offset the number of items.
     * Default: 20. Max: 50.
     */
    paging?: Paging;
}
interface ListChildAccountsResponse {
    /** The requested child accounts. */
    childAccounts?: AccountV2[];
    /** Metadata of the response pagination. */
    pagingMetadata?: PagingMetadata;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function createAccount(): __PublicMethodMetaInfo<'POST', {}, CreateAccountRequest$1, CreateAccountRequest, CreateAccountResponse$1, CreateAccountResponse>;
declare function createAccountForMyUser(): __PublicMethodMetaInfo<'POST', {}, CreateAccountForMyUserRequest$1, CreateAccountForMyUserRequest, AccountResponse$1, AccountResponse>;
declare function listChildAccounts(): __PublicMethodMetaInfo<'GET', {}, ListChildAccountsRequest$1, ListChildAccountsRequest, ListChildAccountsResponse$1, ListChildAccountsResponse>;

export { type __PublicMethodMetaInfo, createAccount, createAccountForMyUser, listChildAccounts };
