// src/identity-account-v2-account-accounts.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressAccountApiAccountServiceUrl(opts) {
  const domainToMappings = {
    "api._api_base_domain_": [
      {
        srcPath: "/account-server",
        destPath: ""
      }
    ],
    "www._base_domain_": [
      {
        srcPath: "/_api/account-server",
        destPath: ""
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/account-server",
        destPath: ""
      },
      {
        srcPath: "/account-server",
        destPath: ""
      }
    ],
    "premium._base_domain_": [
      {
        srcPath: "/_api/account-server",
        destPath: ""
      }
    ],
    "editor._base_domain_": [
      {
        srcPath: "/_api/account-server",
        destPath: ""
      }
    ],
    "blocks._base_domain_": [
      {
        srcPath: "/_api/account-server",
        destPath: ""
      }
    ],
    "create.editorx": [
      {
        srcPath: "/_api/account-server",
        destPath: ""
      }
    ],
    "bo._base_domain_": [
      {
        srcPath: "/account-server",
        destPath: ""
      }
    ],
    "wixbo.ai": [
      {
        srcPath: "/account-server",
        destPath: ""
      }
    ],
    "wix-bo.com": [
      {
        srcPath: "/account-server",
        destPath: ""
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/accounts",
        destPath: ""
      },
      {
        srcPath: "/accounts/v1/accounts",
        destPath: "/v1/accounts"
      },
      {
        srcPath: "/accounts/v1/account",
        destPath: "/v1/account"
      }
    ],
    "users._base_domain_": [
      {
        srcPath: "/_api/account-server",
        destPath: ""
      }
    ],
    "*.dev.wix-code.com": [
      {
        srcPath: "/_api/account-server",
        destPath: ""
      }
    ],
    "twins._base_domain_": [
      {
        srcPath: "/_api/account-server",
        destPath: ""
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_user-management_accounts";
function createAccount(payload) {
  function __createAccount({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.account.v2.account",
      method: "POST",
      methodFqn: "com.wixpress.account.api.AccountService.createAccount",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAccountApiAccountServiceUrl({
        protoPath: "/v1/accounts/create",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __createAccount;
}
function createAccountForMyUser(payload) {
  function __createAccountForMyUser({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.account.v2.account",
      method: "POST",
      methodFqn: "com.wixpress.account.api.AccountService.createAccountForMyUser",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAccountApiAccountServiceUrl({
        protoPath: "/v1/accounts",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "account.dateCreated" },
            { path: "account.dateUpdated" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __createAccountForMyUser;
}
function listChildAccounts(payload) {
  function __listChildAccounts({ host }) {
    const metadata = {
      entityFqdn: "wix.identity.account.v2.account",
      method: "GET",
      methodFqn: "com.wixpress.account.api.AccountService.listChildAccounts",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressAccountApiAccountServiceUrl({
        protoPath: "/v1/account/child-accounts",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __listChildAccounts;
}

// src/identity-account-v2-account-accounts.meta.ts
function createAccount2() {
  const payload = {};
  const getRequestOptions = createAccount(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/accounts/create",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function createAccountForMyUser2() {
  const payload = {};
  const getRequestOptions = createAccountForMyUser(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/accounts",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function listChildAccounts2() {
  const payload = {};
  const getRequestOptions = listChildAccounts(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/v1/account/child-accounts",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
export {
  createAccount2 as createAccount,
  createAccountForMyUser2 as createAccountForMyUser,
  listChildAccounts2 as listChildAccounts
};
//# sourceMappingURL=meta.mjs.map